# Penitus

Penitus is a package used for checking cryptocurrencies, via [Coinpaprika]("https://api.coinpaprika.com/")

## Installation
```bash
pip install penitus
```

## License
[MIT](https://choosealicense.com/licenses/mit/)